@@ -2,8 +2,12 @@
 
 #define QT_FEATURE_webengine_system_alsa 1
 
+#define QT_FEATURE_webengine_v8_context_snapshot 1
+
 #define QT_FEATURE_webengine_system_pulseaudio 1
 
+#define QT_FEATURE_webengine_system_gbm 1
+
 #define QT_FEATURE_webengine_printing_and_pdf 1
 
 #define QT_FEATURE_webengine_pepper_plugins 1
@@ -22,5 +26,5 @@
 
 #define QT_FEATURE_webengine_vulkan 1
 
-#define QT_FEATURE_webengine_system_poppler -1
+#define QT_FEATURE_webengine_vaapi 1
 
